;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
;+
; NAME: DOMDEF
;
; PURPOSE:permet d'extraire un sous domaine d'etude en fournissant les
; parametres necessaires pour les traces. (cf. outputs)
;
; CATEGORY:
;
; CALLING SEQUENCE:domdef [,lon1, lon2, lat1, lat2[,prof1,prof2]] ou
;             bien domdef,vecteur
;
; INPUTS:(facultatif), [vecteur a] 2, 4 ou 6 elements:;
; sans l''utilisation des mots cles index,xindex,yindex,zindex:
; *prof1, prof2: pour un domaine 3D dont la partie horizontale couvre tout
;  glam et gphi
; *lon1, lon2, lat1, lat2:
; definissant les longitudes min. max et les latitudes min, max du  domaine a
; etudier (tous les niveaux sont selectiones)
; *lon1,lon2,lat1,lat2,prof1,prof2 pour specifier les profondeurs.
;
; KEYWORD PARAMETERS:
;
;       FINDALWAYS:oblige a redefinir une boite meme qd auqun point
;       n''est trouve ds la boite. dans ce cas on selectionne toute la
;       grille.
;
;	GRILLE:un string ou un vecteur de string contennant le nom des
;	grilles (determinees uniquement par : 'T','U','V','W','F') pour
;	lesquelles le calcul doit etre fait. par
;	ex :'T' ou ['T','U']
;
;       /MEMEINDICES: il se peut que les points t,u,v et F correspondant a
;       une meme boite geographique ne concernent pas les memes
;       indices des tableaux. Ceci pose parfois de pb (ou du moins de
;       serieuses complications) ds les programmes ou plusieurs types
;       de grilles interviennent (cf.: norme, curl...). Activer
;       MEMEINDICES pour forcer domdef a prendre les memes indices -ceux
;       de la grille T- pour toutes les autres grilles.
;
;       /INDEX: activer si on veut specifier que tous les elements
;       passes en entree de domdef se rapportent aux indices des
;       tableaux glam, gphi et gdep plutot qu'aux valeurs de ces
;       tableaux
;
;       /xindex: activer si on veut que les elements passes en entrre
;       de domdef et concernant la dimension en x se rapportent aux
;       indices des tableaux glam qu'aux valeurs de ces tableaux.
;
;       /yindex: cf xindex mais pour y et les gphi
;
;       /zindex: cf xindex mais pour z et les gdep
;
; OUTPUTS:on recupere pour les 4 grilles t,u,v,f
;   -nxt,u,v:entier qui contient le nombre de pts en longitude de
;    la grille reduite au domaine
;   -nyt,u,v:entier qui contient le nombre de pts en latitude de
;    la grille reduite au domaine
;   -nzt,w:entier qui contient le nombre de pts en profondeur de
;    la grille reduite au domaine 3D
;   -premierxt,u,v,f: le premier indice qui delimite le sous domaine
;   suivant x
;   -premieryt,u,v,f: le premier indice qui delimite le sous domaine
;   suivant y
;   -premierzt,w: le premier indice qui delimite le sous domaine
;   suivant z
;   -dernierxt,u,v,f: le dernier indice qui delimite le sous domaine
;   suivant x
;   -dernieryt,u,v,f: le dernier indice qui delimite le sous domaine
;   suivant y
;   -dernierzt,w: le dernier indice qui delimite le sous domaine
;   suivant z
;
; COMMON BLOCKS:
;	common.pro
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;
; EXAMPLE:
;
; MODIFICATION HISTORY: Sebastien Masson (smasson@lodyc.jussieu.fr)
;			8/2/98
;-
;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
pro domdef,x1,x2,y1,y2,z1,z2, FINDALWAYS = findalways, GRILLE=grille, MEMEINDICES = memeindices, XINDEX = xindex, YINDEX = yindex, ZINDEX = zindex, INDEX = index, _extra = ex
@common
   tempsun = systime(1)         ; pour key_performance
;-------------------------------------------------------------------
; determination en fonction du nombre d''arguments de
; lon1,lon2,lat1,lat2,prof1,prof2
;-------------------------------------------------------------------
   if not keyword_set(grille) then grille=['T', 'U', 'V', 'W', 'F'] ELSE $ 
    for i = 0, n_elements(grille)-1 do grille[i] = strupcase(grille[i])
   if keyword_set(memeindices) then grille=['T', grille]
   CASE N_PARAMS() OF
      0: BEGIN
; lon1 et lon2
         test = 1
         IF (where(grille eq 'T'))[0] NE -1 THEN test = [test, glamt[*]]
         IF (where(grille eq 'W'))[0] NE -1 AND (where(grille eq 'T'))[0] EQ -1 THEN $
          test = [test, glamt[*]]
         IF (where(grille eq 'U'))[0] NE -1 AND n_elements(glamu) NE 0 THEN test = [test, glamu[*]]
         IF (where(grille eq 'V'))[0] NE -1 AND n_elements(glamv) NE 0 THEN test = [test, glamv[*]]
         IF (where(grille eq 'F'))[0] NE -1 AND n_elements(glamf) NE 0 THEN test = [test, glamf[*]]
         test = test[1:n_elements(test)-1] 
         lon1=min([test], max = max)
         lon2=max
; lat1 et lat2
         test = 1
         IF (where(grille eq 'T'))[0] NE -1 THEN test = [test, gphit[*]]
         IF (where(grille eq 'W'))[0] NE -1 AND (where(grille eq 'T'))[0] EQ -1 THEN $
          test = [test, gphit[*]]
         IF (where(grille eq 'U'))[0] NE -1 AND n_elements(gphiu) NE 0 THEN test = [test, gphiu[*]]
         IF (where(grille eq 'V'))[0] NE -1 AND n_elements(gphiv) NE 0 THEN test = [test, gphiv[*]]
         IF (where(grille eq 'F'))[0] NE -1 AND n_elements(gphif) NE 0 THEN test = [test, gphif[*]]
         test = test[1:n_elements(test)-1] 
         lat1=min([test], max = max)
         lat2=max
; prof1 et prof2
         prof1=0
         test = 1
         IF (inter(byte(grille), byte(['T', 'U', 'V', 'F'])))[0] NE -1 THEN test = [test, gdept[jpk-1]]
         IF (where(grille eq 'W'))[0] NE -1 AND n_elements(gdepw) NE 0 THEN test = [test, gdepw[jpk-1]]
         test = test[1:n_elements(test)-1] 
         prof2=max([test])
      end
      1: BEGIN
         xx1 = reform(x1)
         taille = size(xx1)
         CASE taille[1] OF
            2:domdef, xx1[0], xx1[1]                                , FINDALWAYS = findalways,GRILLE=grille, MEMEINDICES = memeindices, XINDEX = xindex, YINDEX = yindex, ZINDEX = zindex, INDEX = index, _extra = ex
            4:domdef, xx1[0], xx1[1], xx1[2], xx1[3]                , FINDALWAYS = findalways,GRILLE=grille, MEMEINDICES = memeindices, XINDEX = xindex, YINDEX = yindex, ZINDEX = zindex, INDEX = index, _extra = ex
            6:domdef, xx1[0], xx1[1], xx1[2], xx1[3], xx1[4], xx1[5], FINDALWAYS = findalways,GRILLE=grille, MEMEINDICES = memeindices, XINDEX = xindex, YINDEX = yindex, ZINDEX = zindex, INDEX = index, _extra = ex
            else: begin
               ras = report('Mauvais nombre de parametre dans l''appel de DOMDEF')
               return
            end
         ENDCASE
         return
      end
      2: begin
; lon1 et lon2
         IF (inter(byte(grille), byte(['T', 'U', 'V', 'F'])))[0] NE -1 THEN BEGIN
            ouca = where(gdept ge prof1 and gdept le prof2,nzt)
            if ouca[0] NE -1 then zt=gdept[ouca] ELSE zt = -1
         ENDIF
         if (where(grille eq 'W'))[0] NE -1 AND n_elements(gdepw) NE 0 then BEGIN
            ouca = where(gdepw ge prof1 and gdepw le prof2,nzw)
            if ouca[0] NE -1 then zw=gdepw[ouca] ELSE zw = -1
         ENDIF
         test = 1
         IF (where(grille eq 'T'))[0] NE -1 THEN test = [test, glamt[*]]
         IF (where(grille eq 'W'))[0] NE -1 AND (where(grille eq 'T'))[0] EQ -1 THEN $
          test = [test, glamt[*]]
         IF (where(grille eq 'U'))[0] NE -1 AND n_elements(glamu) NE 0 THEN test = [test, glamu[*]]
         IF (where(grille eq 'V'))[0] NE -1 AND n_elements(glamv) NE 0 THEN test = [test, glamv[*]]
         IF (where(grille eq 'F'))[0] NE -1 AND n_elements(glamf) NE 0 THEN test = [test, glamf[*]]
         test = test[1:n_elements(test)-1] 
         lon1=min([test], max = max)
         lon2=max
; lat1 et lat2
         test = 1
         IF (where(grille eq 'T'))[0] NE -1 THEN test = [test, gphit[*]]
         IF (where(grille eq 'W'))[0] NE -1 AND (where(grille eq 'T'))[0] EQ -1 THEN $
          test = [test, gphit[*]]
         IF (where(grille eq 'U'))[0] NE -1 AND n_elements(gphiu) NE 0 THEN test = [test, gphiu[*]]
         IF (where(grille eq 'V'))[0] NE -1 AND n_elements(gphiv) NE 0 THEN test = [test, gphiv[*]]
         IF (where(grille eq 'F'))[0] NE -1 AND n_elements(gphif) NE 0 THEN test = [test, gphif[*]]
         test = test[1:n_elements(test)-1] 
         lat1=min([test], max = max)
         lat2=max
; prof1 et prof2
         if keyword_set(zindex) OR keyword_set(index) then BEGIN
            z1 = x1
            z2 = x2
            IF (inter(byte(grille), byte(['T', 'U', 'V', 'F'])))[0] NE -1 THEN prof1 = gdept[z1] ELSE prof1=gdepw[z1]
            if (where(grille eq 'W'))[0] NE -1 AND n_elements(gdepw) NE 0 then prof2=gdepw[z2] ELSE prof2=gdept[z2]
         ENDIF ELSE BEGIN
            prof1=x1
            prof2=x2
         ENDELSE 
      end
      4: begin 
; lon1 et lon2
         if keyword_set(xindex) OR keyword_set(index) then BEGIN
            if keyword_set(yindex) OR keyword_set(index) then BEGIN
               if n_elements(glamf) NE 0 then BEGIN
               lon1 = min([glamt[x1:x2, y1:y2], glamf[x1:x2, y1:y2]], max = lon2)
               ENDIF ELSE BEGIN 
               lon1 = min(glamt[x1:x2, y1:y2], max = lon2)
               ENDELSE
            ENDIF ELSE BEGIN 
               lon1 = glamt[x1, 0]
               if n_elements(glamf) NE 0 then lon2 = glamf[x2, 0] $
               ELSE lon2 = glamt[x2, 0]
            ENDELSE
         ENDIF ELSE BEGIN
            lon1=x1
            lon2=x2
         ENDELSE 
; lat1 et lat2
         if keyword_set(yindex) OR keyword_set(index) then BEGIN
            if keyword_set(xindex) OR keyword_set(index) then begin
               lat1 = min([gphit[x1, y1], gphit[x2, y1]])
               if n_elements(gphif) NE 0 then lat2 = max([gphif[x1, y2], gphif[x2, y2]]) $
               ELSE lat2 = max([gphit[x1, y2], gphit[x2, y2]])
            ENDIF ELSE BEGIN 
               lat1 = gphit[0, y1]
               if n_elements(gphif) NE 0 then lat2 = gphif[0, y2] $
               ELSE lat2 = gphit[0, y2]
            ENDELSE
         ENDIF ELSE BEGIN
            lat1=y1
            lat2=y2
         ENDELSE 
; prof1 et prof2
         prof1=0
         test = 1
         IF (inter(byte(grille), byte(['T', 'U', 'V', 'F'])))[0] NE -1 THEN test = [test, gdept[jpk-1]]
         IF (where(grille eq 'W'))[0] NE -1 AND n_elements(gdepw) NE 0 THEN test = [test, gdepw[jpk-1]]
         test = test[1:n_elements(test)-1] 
         prof2=max([test])
      end
      6: begin 
; lon1 et lon2
         if keyword_set(xindex) OR keyword_set(index) then BEGIN
            if keyword_set(yindex) OR keyword_set(index) then begin
               lon1 = min([glamt[x1, y1], glamt[x1, y2]])
               if n_elements(glamf) NE 0 then lon2 = max([glamf[x2, y1], glamf[x2, y2]]) $
               ELSE lon2 = max([glamt[x2, y1], glamt[x2, y2]])
            ENDIF ELSE BEGIN 
               lon1 = glamt[x1, 0]
               if n_elements(glamf) NE 0 then lon2 = glamf[x2, 0] $
               ELSE lon2 = glamt[x2, 0]
            ENDELSE
         ENDIF ELSE BEGIN
            lon1=x1
            lon2=x2
         ENDELSE 
; lat1 et lat2
         if keyword_set(yindex) OR keyword_set(index) then BEGIN
            if keyword_set(xindex) OR keyword_set(index) then begin
               lat1 = min([gphit[x1, y1], gphit[x2, y1]])
               if n_elements(gphif) NE 0 then lat2 = max([gphif[x1, y2], gphif[x2, y2]]) $
               ELSE lat2 = max([gphit[x1, y2], gphit[x2, y2]])
            ENDIF ELSE BEGIN 
               lat1 = gphit[0, y1]
               if n_elements(gphif) NE 0 then lat2 = gphif[0, y2] $
               ELSE lat2 = gphit[0, y2]
            ENDELSE
         ENDIF ELSE BEGIN
            lat1=y1
            lat2=y2
         ENDELSE 
; prof1 et prof2
         if keyword_set(zindex) OR keyword_set(index) then begin
            IF (inter(byte(grille), byte(['T', 'U', 'V', 'F'])))[0] NE -1 THEN prof1=gdept[z1] ELSE prof1=gdepw[z1]
            if (where(grille eq 'W'))[0] NE -1 AND n_elements(gdepw) NE 0 then prof2=gdepw[z2] ELSE prof2=gdept[z2]
         ENDIF ELSE BEGIN
            prof1=z1
            prof2=z2
         ENDELSE 
      end
      else: begin
         ras = report('Mauvais nombre de parametre dans l''appel de DOMDEF')
         return
      end
   endcase  
;----------------------------------------------------------------------       
; determination de nzt et nwt
;----------------------------------------------------------------------       
   IF (inter(byte(grille), byte(['T', 'U', 'V', 'F'])))[0] NE -1 THEN BEGIN
      if keyword_set(zindex) OR keyword_set(index) then nzt = z2-z1+1 $
      ELSE BEGIN 
         ouca = where(gdept ge prof1 and gdept le prof2,nzt)
         if ouca[0] NE -1 then zt=gdept[ouca] ELSE zt = -1
      ENDELSE
   ENDIF
   if (where(grille eq 'W'))[0] NE -1 AND n_elements(gdepw) NE 0 then BEGIN
      if keyword_set(zindex) OR keyword_set(index) then nzw = z2-z1+1 $
      ELSE BEGIN 
         ouca = where(gdepw ge prof1 and gdepw le prof2,nzw)
         if ouca[0] NE -1 then zw=gdepw[ouca] ELSE zw = -1
      ENDELSE
   ENDIF
;----------------------------------------------------------------------       
; determination de premierzt, dernierzt, premierzw, dernierzw
;----------------------------------------------------------------------       
   IF (inter(byte(grille), byte(['T', 'U', 'V', 'F'])))[0] NE -1 THEN BEGIN
      if keyword_set(zindex) OR keyword_set(index) then BEGIN 
         premierzt = z1
         dernierzt = z2
      ENDIF ELSE BEGIN 
         if zt[0] NE -1 then begin
            premierzt = (where(gdept eq zt[0]))[0]
            dernierzt = (where(gdept eq zt[nzt-1]))[0]
         ENDIF ELSE BEGIN 
            premierzt = -1
            dernierzt = -1
         ENDELSE
      ENDELSE
   endif
   if (where(grille eq 'W'))[0] NE -1  AND n_elements(gdepw) NE 0 then begin
      if keyword_set(zindex) OR keyword_set(index) then BEGIN 
         premierzw = z1
         dernierzw = z2
      ENDIF ELSE BEGIN 
         if zw[0] NE -1 then begin
            premierzw = (where(gdepw eq zw[0]))[0]
            dernierzw = (where(gdepw eq zw[nzw-1]))[0]
         ENDIF ELSE BEGIN 
            premierzw = -1
            dernierzw = -1
         ENDELSE
      ENDELSE
   endif
;-------------------------------------------------------------------
;-------------------------------------------------------------------
; calcul pour les pts t et w
;-------------------------------------------------------------------
;-------------------------------------------------------------------
   tempdeux = systime(1)        ; pour key_performance =2
   if (where(grille eq 'T'))[0] NE -1 or (where(grille EQ 'W'))[0] NE -1 then begin
      if (keyword_set(xindex) AND keyword_set(yindex)) OR keyword_set(index) then begin
         premierxt = x1
         premieryt = y1
         dernierxt = x2
         dernieryt = y2
      ENDIF ELSE BEGIN
         dom =   where( (glamt ge lon1) $
                        and (glamt le lon2) $
                        and (gphit ge lat1) $
                        and (gphit le lat2) )
         if (dom[0] eq -1) then BEGIN
            if keyword_set(findalways) then BEGIN
               domdef, prof1,prof2, GRILLE=grille, MEMEINDICES = memeindices, _extra = ex
               return
            ENDIF ELSE BEGIN
               ras = report('ATTENTION, la boite ne contient pas de points t')
               goto, ptu
            ENDELSE
         endif 
         IF testvar(var = key_performance) EQ 2 THEN $
          print, 'temps domdef: trouver le sous domaine', systime(1)-tempdeux
;-------------------------------------------------------------------
; on recupere les abscisses et les ordonees des points selectionnes
;-------------------------------------------------------------------
         tempdeux = systime(1)  ; pour key_performance =2
         ordonnee = dom/jpi
         abscisse = dom-ordonnee*jpi
;-------------------------------------------------------------------
; on les ordonnes et on elimine les elements en double
;-------------------------------------------------------------------
         ordonnee = ordonnee
         abscisse = abscisse
         ordonnee = ordonnee(uniq(ordonnee, sort(ordonnee)))
         abscisse = abscisse(uniq(abscisse, sort(abscisse)))
;-------------------------------------------------------------------
; indices des bornes du domaine
;-------------------------------------------------------------------
         premierxt = abscisse[0]
         premieryt = ordonnee[0]
         dernierxt = abscisse[n_elements(abscisse) -1]
         dernieryt = ordonnee[n_elements(ordonnee) -1]
      ENDELSE 
;-------------------------------------------------------------------
; nombre de points selectionnes
;-------------------------------------------------------------------
      nxt = dernierxt-premierxt+1
      nyt = dernieryt-premieryt+1
      IF testvar(var = key_performance) EQ 2 THEN $
       print, 'temps domdef: calculs de premier, dernier,...', systime(1)-tempdeux
;-------------------------------------------------------------------
; la grille est reguliere ou non ??
;-------------------------------------------------------------------
      tempdeux = systime(1)     ; pour key_performance =2
      if (total(glamt[premierxt:dernierxt,premieryt:dernieryt] $
                NE glamt[premierxt:dernierxt,0]#replicate(1, nyt)) eq 0 $
          AND total(gphit[premierxt:dernierxt,premieryt:dernieryt] $
                    NE replicate(1, nxt)#(gphit[0,premieryt:dernieryt])[*]) eq 0 ) $
       then key_irregular = 0 ELSE key_irregular = 1
      IF testvar(var = key_performance) EQ 2 THEN $
       print, 'temps domdef: la grille est reguliere ou non ', systime(1)-tempdeux
;-------------------------------------------------------------------
      if keyword_set(memeindices) then begin
         premierxu = premierxt & premierxv = premierxt & premierxf = premierxt 
         dernierxu = dernierxt & dernierxv = dernierxt & dernierxf = dernierxt
         premieryu = premieryt & premieryv = premieryt & premieryf = premieryt 
         dernieryu = dernieryt & dernieryv = dernieryt & dernieryf = dernieryt
         premierzw = premierzt 
         dernierzw = dernierzt 
         nxu = nxt & nxv = nxt & nxf = nxt
         nyu = nyt & nyv = nyt & nyf = nyt
         nzw = nzt
         lon1 = glamt[premierxt, 0]
         lon2 = glamf[dernierxf, 0]
         lat1 = gphit[0, premieryt]
         lat2 = gphif[0, dernieryf]
         return
      endif
ptu:
   endif
;-------------------------------------------------------------------
; calcul pour les pts u
;-------------------------------------------------------------------
   if (where(grille eq 'U'))[0] NE -1 then begin
      if (keyword_set(xindex) AND keyword_set(xindex)) OR keyword_set(index) then begin
         premierxu = x1
         premieryu = y1
         dernierxu = x2
         dernieryu = y2
      ENDIF ELSE BEGIN
         dom =   where( (glamu ge lon1) $
                        and (glamu le lon2) $
                        and (gphiu ge lat1) $
                        and (gphiu le lat2) )
         if (dom[0] eq -1) then begin
            if keyword_set(findalways) then begin
               domdef, prof1,prof2, GRILLE=grille, MEMEINDICES = memeindices, _extra = ex
               return
            ENDIF ELSE BEGIN
               ras = report('ATTENTION, la boite ne contient pas de points u')
               goto, ptv
            ENDELSE
         ENDIF
         ordonnee = dom/jpi
         abscisse = dom-ordonnee*jpi
         ordonnee = ordonnee(uniq(ordonnee, sort(ordonnee)))
         abscisse = abscisse(uniq(abscisse, sort(abscisse)))
         premierxu = abscisse[0]
         premieryu = ordonnee[0]
         dernierxu = abscisse[n_elements(abscisse) -1]
         dernieryu = ordonnee[n_elements(ordonnee) -1]
      ENDELSE 
      nxu = dernierxu-premierxu+1
      nyu = dernieryu-premieryu+1
      if (total(glamu[premierxu:dernierxu,premieryu:dernieryu] $
                NE glamu[premierxu:dernierxu,0]#replicate(1, nyu)) eq 0 $
          AND total(gphiu[premierxu:dernierxu,premieryu:dernieryu] $
                    NE replicate(1, nxu)#(gphiu[0,premieryu:dernieryu])[*]) eq 0 ) $
       then key_irregular = 0 ELSE key_irregular = 1
ptv:
   endif
;-------------------------------------------------------------------
; calcul pour les pts v
;-------------------------------------------------------------------
   if (where(grille eq 'V'))[0] NE -1 then begin
      if (keyword_set(xindex) AND keyword_set(xindex)) OR keyword_set(index) then begin
         premierxv = x1
         premieryv = y1
         dernierxv = x2
         dernieryv = y2
      ENDIF ELSE BEGIN
         dom =   where( (glamv ge lon1) $
                        and (glamv le lon2) $
                        and (gphiv ge lat1) $
                        and (gphiv le lat2) )
         if (dom[0] eq -1) then begin
            if keyword_set(findalways) then begin
               domdef, prof1,prof2, GRILLE=grille, MEMEINDICES = memeindices, _extra = ex
               return
            ENDIF ELSE BEGIN
               ras = report('ATTENTION, la boite ne contient pas de points v')
               goto, ptf
            ENDELSE
         ENDIF
         ordonnee = dom/jpi
         abscisse = dom-ordonnee*jpi
         ordonnee = ordonnee(uniq(ordonnee, sort(ordonnee)))
         abscisse = abscisse(uniq(abscisse, sort(abscisse)))
         premierxv = abscisse[0]
         premieryv = ordonnee[0]
         dernierxv = abscisse[n_elements(abscisse) -1]
         dernieryv = ordonnee[n_elements(ordonnee) -1]
      ENDELSE 
      nxv = dernierxv-premierxv+1
      nyv = dernieryv-premieryv+1
      if (total(glamv[premierxv:dernierxv,premieryv:dernieryv] $
                NE glamv[premierxv:dernierxv,0]#replicate(1, nyv)) eq 0 $
          AND total(gphiv[premierxv:dernierxv,premieryv:dernieryv] $
                    NE replicate(1, nxv)#(gphiv[0,premieryv:dernieryv])[*]) eq 0 ) $
       then key_irregular = 0 ELSE key_irregular = 1
ptf:
   endif
;-------------------------------------------------------------------
; calcul pour les pts f
;-------------------------------------------------------------------
   if (where(grille eq 'F'))[0] NE -1 then begin
      if (keyword_set(xindex) AND keyword_set(xindex)) OR keyword_set(index) then begin
         premierxf = x1
         premieryf = y1
         dernierxf = x2
         dernieryf = y2
      ENDIF ELSE BEGIN
         dom =   where( (glamf ge lon1) $
                        and (glamf le lon2) $
                        and (gphif ge lat1) $
                        and (gphif le lat2) )
         if (dom[0] eq -1) then begin
            if keyword_set(findalways) then begin
               domdef, prof1,prof2, GRILLE=grille, MEMEINDICES = memeindices, _extra = ex
               return
            ENDIF ELSE BEGIN
               ras = report('ATTENTION, la boite ne contient pas de points f')
               return
            ENDELSE
         ENDIF
         ordonnee = dom/jpi
         abscisse = dom-ordonnee*jpi
         ordonnee = ordonnee(uniq(ordonnee, sort(ordonnee)))
         abscisse = abscisse(uniq(abscisse, sort(abscisse)))
         premierxf = abscisse[0]
         premieryf = ordonnee[0]
         dernierxf = abscisse[n_elements(abscisse) -1]
         dernieryf = ordonnee[n_elements(ordonnee) -1]
      ENDELSE
      nxf = dernierxf-premierxf+1
      nyf = dernieryf-premieryf+1
      if (total(glamf[premierxf:dernierxf,premieryf:dernieryf] $
                NE glamf[premierxf:dernierxf,0]#replicate(1, nyf)) eq 0 $
          AND total(gphif[premierxf:dernierxf,premieryf:dernieryf] $
                    NE replicate(1, nxf)#(gphif[0,premieryf:dernieryf])[*]) eq 0 ) $
       then key_irregular = 0 ELSE key_irregular = 1
   endif
;-------------------------------------------------------------------
   if keyword_set(key_performance) THEN print, 'temps domdef', systime(1)-tempsun 
;-------------------------------------------------------------------

;-------------------------------------------------------------------
   return
end
